import { Injectable } from '@angular/core';
import Joi from '@hapi/joi';

@Injectable({
  providedIn: 'root'
})
export class ValidationService {

  private vUsername = Joi.string()
    .lowercase()
    .pattern(new RegExp('^[a-z0-9-_.]+$'))
    .min(1)
    .max(128);

  private vPassword = Joi.string()
    .pattern(new RegExp('^(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z])(?=.*[!"#%&\'()*+,-.\\/:;<=>?@[\\]^_`{|}~])(?=\\S+$).{8,}$'))
    .max(128);

  constructor() { }

  username(data) {
    const {ignore, error} = this.vUsername.validate(data);
    if (error) {
      return {ok: false, error: 'username must only contain a-z0-9-_.'};
    }
    return {ok: true, error: ''};
  }

  password(data) {
    const {ignore, error} = this.vPassword.validate(data);
    if (error) {
      return {ok: false, error: 'password must only contain a-zA-Z0-9!"#%&\'()*+,-./:;<=>?@[]^_`{|}~'};
    }
    return {ok: true, error: ''};
  }
}
